@@ -10,6 +10,54 @@ import numpy as np
 WGS84_A = 6378137.0
 WGS84_E = 8.1819190842622e-2
 
+class Coordinates(object):
+
+    def __init__(self, x, y, z):
+
+        self.x = x
+        self.y = y
+        self.z = z
+
+    def is_valid(self):
+        """
+        >>> coordinates = Coordinates(0, 0, 0)
+        >>> coordinates.is_valid()
+        False
+        """
+        return valid_coordinates(xyz=self.xyz())
+
+    def xyz(self):
+        return [self.x, self.y, self.z]
+
+    def lla(self, radians=False, a=WGS84_A, e=WGS84_E):
+        return xyz_to_lla(self.x, self.y, self.z, radians=radians, a=a, e=e)
+
+    def __repr__(self):
+        return f'{self.x:.3f} {self.y:.3f} {self.z:.3f}'
+
+    @staticmethod
+    def from_lla(longitude_deg, latitude_deg, height_m, a=WGS84_A, e=WGS84_E):
+        """
+        >>> coordinates = Coordinates.from_lla(2, 40, 100)
+        >>> coordinates.is_valid()
+        True
+        """
+
+        xyz = lla_to_xyz(longitude_deg, latitude_deg, height_m, a=a, e=e)
+
+        return Coordinates(*xyz)
+
+    @staticmethod
+    def from_xyz(x, y, z):
+        """
+        >>> coordinates = Coordinates.from_lla(4889803.653, 170755.706, 4078049.851)
+        >>> coordinates.is_valid()
+        True
+        """
+
+        return Coordinates(x, y, z)
+        
+
 def valid_coordinates(lla=None, xyz=None):
     """
     Check wether the input geographic coordinates are valid or not (in terms
